@@ -2,10 +2,11 @@ import scipy.io as sio
 import numpy as np
 import matplotlib.pyplot as plt
 # from process import denoise
-from deeg.check import check_nan
-from deeg.band import band
-from deeg.sampling import sampling
-from deeg.segment import segment
+# from deeg.check import check_nan
+# from deeg.band import band
+# from deeg.sampling import sampling
+# from deeg.segment import segment
+from deeg.features import cal_eeg_features
 
 data_dir = "D:/EEG/data_preprocessed_matlab/"
 
@@ -16,12 +17,20 @@ single_s01_data = s01_data[0,0,:]
 print(s01_data.shape, single_s01_data.shape)
 print(len(s01_data.shape), len(single_s01_data.shape))
 
-# ----- Process: segment -----
-segmented_array = segment(single_s01_data, length=10, overlap=3)
+# ----- Extract all features -----
+eeg_features, feature_list = cal_eeg_features(s01_data, 1000, 2000)
+print(eeg_features.shape)
+# from deeg.features import power_spectral_density
+# a = power_spectral_density(single_s01_data, 1000, 2000)
+# print(a)
 
-print(segmented_array[0].shape, segmented_array[1].shape)
-print(single_s01_data[:20])
-print(segmented_array.shape)
+
+# ----- Process: segment -----
+# segmented_array = segment(single_s01_data, length=10, overlap=3)
+#
+# print(segmented_array[0].shape, segmented_array[1].shape)
+# print(single_s01_data[:20])
+# print(segmented_array.shape)
 
 
 
